@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11326 2019-01-08 18:50:45Z Lavender $
+# $Id: __init__.py 11339 2019-01-15 14:56:17Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-01-09 03:50:45 +0900 (週三, 09 一月 2019) $
-# $Revision: 11326 $
+# $Date: 2019-01-15 23:56:17 +0900 (週二, 15 一月 2019) $
+# $Revision: 11339 $
 
 import os
 import sys
@@ -369,11 +369,13 @@ def attachSettings(settingsDict, enablePaypal=False):
         'OSCAR_INITIAL_ORDER_STATUS',
         'OSCAR_INITIAL_LINE_STATUS',
         'OSCAR_ORDER_STATUS_PIPELINE',
-        'OSCAR_ORDER_SEND_EMAIL_STATUS',
+        'OSCAR_PROCESSING_SEND_EMAIL_STATUS',
+        'OSCAR_ARRIVE_SEND_EMAIL_STATUS',
 
         'OSCAR_ORDER_RETURN_STATUS',
         'OSCAR_ORDER_PROCESSING_STATUS',
         'OSCAR_ORDER_COMPLETE_STATUS',
+        'OSCAR_ORDER_ARRIVE_STATUS',
     ]
 
     # add default settings
@@ -390,17 +392,21 @@ def attachSettings(settingsDict, enablePaypal=False):
     if not hasConfig:
         if needShipping:
             ADDING_OSCAR_ORDER_STATUS = {
-                'OSCAR_ORDER_SEND_EMAIL_STATUS': u'商品送貨中',
+                'OSCAR_PROCESSING_SEND_EMAIL_STATUS': u'商品送貨中',
+                'OSCAR_ARRIVE_SEND_EMAIL_STATUS': u'商品已到貨',
                 'OSCAR_INITIAL_ORDER_STATUS': u'等待處理中',
                 'OSCAR_INITIAL_LINE_STATUS': '-',
                 'OSCAR_ORDER_RETURN_STATUS': u'商品退貨中',
                 'OSCAR_ORDER_PROCESSING_STATUS': u'商品送貨中',
                 'OSCAR_ORDER_COMPLETE_STATUS': u'完成訂單',
+                'OSCAR_ORDER_ARRIVE_STATUS': u'商品已到貨',
                 'OSCAR_ORDER_STATUS_PIPELINE': {
                     u'等待處理中': \
                         (u'商品送貨中', u'訂單取消', u'測試用訂單'),
                     u'商品送貨中': \
-                        (u'完成訂單', u'訂單取消', u'測試用訂單'),
+                        (u'完成訂單', u'商品已到貨', 
+                         u'訂單取消', u'測試用訂單'),
+                    u'商品已到貨': (u'完成訂單', u'訂單取消', u'測試用訂單',),
                     u'訂單取消': (u'測試用訂單', ),
                     u'完成訂單': (u'測試用訂單', ),
 
